@@ -57,6 +57,9 @@ public:
     /// @since 6.1
     void setTransportActivitiesAbstract(MailTransport::TransportActivitiesAbstract *activitiesAbstract);
 
+    [[nodiscard]] bool enablePlasmaActivities() const;
+    void setEnablePlasmaActivities(bool newEnablePlasmaActivities);
+
 Q_SIGNALS:
     void transportRemoved(Transport::Id id, const QString &name);
 
